His code can further be optimized by having only 1 large element in the iovec (vs. many 2-byte "y\n" elements).
from what i can see it's already in a large iovec buffer
Correct, I misread the code. However bumping the pipe size buffer bumps the speed from 28 to 74 GB/s on my Skylake CPU (i5-6500).
Edit: I optimized further and now get 123 GB/s See https://www.reddit.com/r/unix/comments/6gxduc/how_is_gnu_yes...
https://www.reddit.com/r/unix/comments/6gxduc/how_is_gnu_yes...